import json
import os
import time
import uuid

import schedule
from loguru import logger

from common.aliyun_log import AliyunLogger
from common.redis import get_top_data, in_job_video_data
from top_automatic.top_data_processing import Top


def get_data_task():
    top_tasks = set()  # 使用集合去重
    while True:
        top_task = get_top_data("task:top_all_data")
        if top_task:
            data = json.loads(top_task)
            channel_id = data['channel']
            if channel_id not in ["抖音关键词抓取", "快手关键词抓取", "搬运改造"]:
                logger.info(f"[+] 改内容为:{channel_id},不做处理")
                AliyunLogger.logging(channel_id, data, "不处理",None)
                continue
            top_tasks.add(top_task)
        else:
            return list(top_tasks)

def video_task_start():
    logger.info(f"[+] 任务开始获取小时级top数据")
    data_list = get_data_task()
    logger.info(f"[+] 共获取{len(data_list)}条")
    if not data_list:
        return
    for data in data_list:
        try:
            logger.info(f"[+] 任务处理{data}任务")
            top = Top()
            top.main(data)
            logger.info(f"[+] {data}处理成功")
            time.sleep(5)
            continue
        except Exception as e:
            data = json.loads(data)
            in_job_video_data("task:top_all_data", json.dumps(data, ensure_ascii=False, indent=4))
            AliyunLogger.logging(data['channel'], data, "处理失败重新处理",None)
            logger.error(f"[+] {data}处理失败,失败信息{e}")
            continue

def schedule_tasks():
    schedule.every(10).minutes.do(video_task_start)

if __name__ == '__main__':
    schedule_tasks()  # 调用任务调度函数
    while True:
        schedule.run_pending()
        time.sleep(1)  # 每秒钟检查一次
    # video_task_start()